# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-04-09 09:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('howl', '0006_auto_20160409_1102'),
    ]

    operations = [
        migrations.AlterField(
            model_name='observer',
            name='value',
            field=models.FloatField(verbose_name='Value'),
        ),
    ]
