# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-01-01 07:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('howl', '0007_auto_20160409_1127'),
    ]

    operations = [
        migrations.AlterField(
            model_name='observer',
            name='operator',
            field=models.CharField(choices=[('EqualOperator', 'Equals'), ('GreaterThanOperator', 'Greater than'), ('LowerThanOperator', 'Lower than'), ('MyOperator', 'My +2')], max_length=32, verbose_name='Operator type'),
        ),
    ]
